searchData={"items":[{"type":"module","title":"Phoenix.LiveReloader","doc":"Router for live-reload detection in development.","ref":"Phoenix.LiveReloader.html"},{"type":"module","title":"Usage - Phoenix.LiveReloader","doc":"Add the `Phoenix.LiveReloader` plug within a `code_reloading?` block\nin your Endpoint, ie:\n\n    if code_reloading? do\n      socket \"/phoenix/live_reload/socket\", Phoenix.LiveReloader.Socket\n      plug Phoenix.CodeReloader\n      plug Phoenix.LiveReloader\n    end","ref":"Phoenix.LiveReloader.html#module-usage"},{"type":"module","title":"Configuration - Phoenix.LiveReloader","doc":"All live-reloading configuration must be done inside the `:live_reload`\nkey of your endpoint, such as this:\n\n    config :my_app, MyApp.Endpoint,\n      ...\n      live_reload: [\n        patterns: [\n          ~r{priv/static/.*(js|css|png|jpeg|jpg|gif)$},\n          ~r{lib/my_app_web/views/.*(ex)$},\n          ~r{lib/my_app_web/templates/.*(eex)$}\n        ]\n      ]\n\nThe following options are supported:\n\n  * `:patterns` - a list of patterns to trigger the live reloading.\n    This option is required to enable any live reloading.\n\n  * `:notify` - a keyword list of topics pointing to a list of patterns.\n    A message of the form `{:phoenix_live_reload, topic, path}` will be\n    broadcast on the topic whenever file in the list of patterns changes.\n\n  * `:debounce` - an integer in milliseconds to wait before sending\n    live reload events to the browser. Defaults to `0`.\n\n  * `:iframe_attrs` - attrs to be given to the iframe injected by\n    live reload. Expects a keyword list of atom keys and string values.\n\n  * `:target_window` - the window that will be reloaded, as an atom.\n    Valid values are `:top` and `:parent`. Defaults to `:parent`.\n\n  * `:url` - the URL of the live reload socket connection. By default\n    it will use the browser's host and port.\n\n  * `:suffix` - if you are running live-reloading on an umbrella app,\n    you may want to give a different suffix to each socket connection.\n    You can do so with the `:suffix` option:\n\n        live_reload: [\n          suffix: \"/proxied/app/path\"\n        ]\n\n    And then configure the endpoint to use the same suffix:\n\n        if code_reloading? do\n          socket \"/phoenix/live_reload/socket/proxied/app/path\", Phoenix.LiveReloader.Socket\n          ...\n        end\n\n  * `:reload_page_on_css_changes` - If true, CSS changes will trigger a full\n    page reload like other asset types instead of the default hot reload.\n    Useful when class names are determined at runtime, for example when\n    working with CSS modules. Defaults to false.\n\n  * `:web_console_logger` - If true, the live reloader will log messages\n    to the web console in your browser. Defaults to false.\n    *Note*: Requires Elixir v1.15+ and your application javascript bundle will need\n    to enable logs. See the README for more information.\n\nIn an umbrella app, if you want to enable live reloading based on code\nchanges in sibling applications, set the `reloadable_apps` option on your\nendpoint to ensure the code will be recompiled, then add the dirs to\n`:phoenix_live_reload` to trigger page reloads:\n\n    # in config/dev.exs\n    root_path =\n      __ENV__.file\n      |> Path.dirname()\n      |> Path.join(\"..\")\n      |> Path.expand()\n\n    config :phoenix_live_reload, :dirs, [\n      Path.join([root_path, \"apps\", \"app1\"]),\n      Path.join([root_path, \"apps\", \"app2\"]),\n    ]\n\nYou'll also want to be sure that the configured `:patterns` for\n`live_reload` will match files in the sibling application.","ref":"Phoenix.LiveReloader.html#module-configuration"},{"type":"function","title":"Phoenix.LiveReloader.call/2","doc":"","ref":"Phoenix.LiveReloader.html#call/2"},{"type":"function","title":"Phoenix.LiveReloader.init/1","doc":"","ref":"Phoenix.LiveReloader.html#init/1"},{"type":"module","title":"Phoenix.LiveReloader.Application","doc":"","ref":"Phoenix.LiveReloader.Application.html"},{"type":"function","title":"Phoenix.LiveReloader.Application.start/2","doc":"","ref":"Phoenix.LiveReloader.Application.html#start/2"},{"type":"function","title":"Phoenix.LiveReloader.Application.start_link/0","doc":"","ref":"Phoenix.LiveReloader.Application.html#start_link/0"},{"type":"module","title":"Phoenix.LiveReloader.Channel","doc":"Phoenix's live-reload channel.","ref":"Phoenix.LiveReloader.Channel.html"},{"type":"function","title":"Phoenix.LiveReloader.Channel.child_spec/1","doc":"","ref":"Phoenix.LiveReloader.Channel.html#child_spec/1"},{"type":"function","title":"Phoenix.LiveReloader.Channel.handle_in/3","doc":"","ref":"Phoenix.LiveReloader.Channel.html#handle_in/3"},{"type":"function","title":"Phoenix.LiveReloader.Channel.handle_info/2","doc":"","ref":"Phoenix.LiveReloader.Channel.html#handle_info/2"},{"type":"function","title":"Phoenix.LiveReloader.Channel.join/3","doc":"","ref":"Phoenix.LiveReloader.Channel.html#join/3"},{"type":"function","title":"Phoenix.LiveReloader.Channel.start_link/1","doc":"","ref":"Phoenix.LiveReloader.Channel.html#start_link/1"},{"type":"module","title":"Phoenix.LiveReloader.Socket","doc":"The Socket handler for live reload channels.","ref":"Phoenix.LiveReloader.Socket.html"},{"type":"function","title":"Phoenix.LiveReloader.Socket.connect/2","doc":"","ref":"Phoenix.LiveReloader.Socket.html#connect/2"},{"type":"function","title":"Phoenix.LiveReloader.Socket.id/1","doc":"","ref":"Phoenix.LiveReloader.Socket.html#id/1"},{"type":"extras","title":"README","doc":"A project for live-reload functionality for [Phoenix](http://github.com/phoenixframework/phoenix) during development.","ref":"readme.html"},{"type":"extras","title":"Usage - README","doc":"You can use `phoenix_live_reload` in your projects by adding it to your `mix.exs` dependencies:\n\n```elixir\ndef deps do\n  [{:phoenix_live_reload, \"~> 1.5\"}]\nend\n```\n\nYou can configure the reloading interval in ms in your `config/dev.exs`:\n\n```elixir\n# Watch static and templates for browser reloading.\nconfig :my_app, MyAppWeb.Endpoint,\n  live_reload: [\n    interval: 1000,\n    patterns: [\n      ...\n```\n\nThe default interval is 100ms.","ref":"readme.html#usage"},{"type":"extras","title":"Streaming serving logs to the web console - README","doc":"> *Note:* This feature is only available for Elixir v1.15+\n\nStreaming server logs that you see in the terminal when running `mix phx.server` can be useful to have on the client during development, especially when debugging with SPA fetch callbacks, GraphQL queries, or LiveView actions in the browsers web console. You can enable log streaming to collocate client and server logs in the web console with the `web_console_logger` configuration in your `config/dev.exs`:\n\n```elixir\nconfig :my_app, MyAppWeb.Endpoint,\n  live_reload: [\n    interval: 1000,\n    patterns: [...],\n    web_console_logger: true\n  ]\n```\n\nNext, you'll need to listen for the `\"phx:live_reload:attached\"` event and enable client logging by calling the reloader's `enableServerLogs()` function, for example:\n\n```javascript\nwindow.addEventListener(\"phx:live_reload:attached\", ({detail: reloader}) => {\n  // enable server log streaming to client.\n  // disable with reloader.disableServerLogs()\n  reloader.enableServerLogs()\n})\n```","ref":"readme.html#streaming-serving-logs-to-the-web-console"},{"type":"extras","title":"Jumping to HEEx function definitions - README","doc":"Many times it's useful to inspect the HTML DOM tree to find where markup is being rendered from within your application. HEEx supports annotating rendered HTML with HTML comments that give you the file/line of a HEEx function component and caller. `:phoenix_live_reload` will look for the `PLUG_EDITOR` environment export (used by the plug debugger page to link to source code) to launch a configured URL of your choice to open your code editor to the file-line of the HTML annotation. For example, the following export on your system would open vscode at the correct file/line:\n\n```\nexport PLUG_EDITOR=\"vscode://file/__FILE__:__LINE__\"\n```\n\nThe `vscode://` protocol URL will open vscode with placeholders of `__FILE__:__LINE__` substituted at runtime. Check your editor's documentation on protocol URL support. To open your configured editor URL when an element is clicked, say with alt-click, you can wire up an event listener within your `\"phx:live_reload:attached\"` callback and make use of the reloader's `openEditorAtCaller` and `openEditorAtDef` functions, passing the event target as the DOM node to reference for HEEx file:line annotation information. For example:\n\n```javascript\nwindow.addEventListener(\"phx:live_reload:attached\", ({detail: reloader}) => {\n  // Enable server log streaming to client. Disable with reloader.disableServerLogs()\n  reloader.enableServerLogs()\n\n  // Open configured PLUG_EDITOR at file:line of the clicked element's HEEx component\n  //\n  //   * click with \"c\" key pressed to open at caller location\n  //   * click with \"d\" key pressed to open at function component definition location\n  let keyDown\n  window.addEventListener(\"keydown\", e => keyDown = e.key)\n  window.addEventListener(\"keyup\", e => keyDown = null)\n  window.addEventListener(\"click\", e => {\n    if(keyDown === \"c\"){\n      e.preventDefault()\n      e.stopImmediatePropagation()\n      reloader.openEditorAtCaller(e.target)\n    } else if(keyDown === \"d\"){\n      e.preventDefault()\n      e.stopImmediatePropagation()\n      reloader.openEditorAtDef(e.target)\n    }\n  }, true)\n  window.liveReloader = reloader\n})\n```","ref":"readme.html#jumping-to-heex-function-definitions"},{"type":"extras","title":"Backends - README","doc":"This project uses [`FileSystem`](https://github.com/falood/file_system) as a dependency to watch your filesystem whenever there is a change and it supports the following operating systems:\n\n* Linux via [inotify](https://github.com/rvoicilas/inotify-tools/wiki) (installation required)\n* Windows via [inotify-win](https://github.com/thekid/inotify-win) (no installation required)\n* Mac OS X via fsevents (no installation required)\n* FreeBSD/OpenBSD/~BSD via [inotify](https://github.com/rvoicilas/inotify-tools/wiki) (installation required)\n\nThere is also a `:fs_poll` backend that polls the filesystem and is available on all Operating Systems in case you don't want to install any dependency. You can configure the `:backend` in your `config/config.exs`:\n\n```elixir\nconfig :phoenix_live_reload,\n  backend: :fs_poll\n```\n\nBy default the entire application directory is watched by the backend. However, with some environments and backends, this may be inefficient, resulting in slow response times to file modifications. To account for this, it's also possible to explicitly declare a list of directories for the backend to watch (they must be relative to the project root, otherwise they are just ignored), and additional options for the backend:\n\n```elixir\nconfig :phoenix_live_reload,\n  dirs: [\n    \"priv/static\",\n    \"priv/gettext\",\n    \"lib/example_web/live\",\n    \"lib/example_web/views\",\n    \"lib/example_web/templates\",\n    \"../another_project/priv/static\", # Contents of this directory is not watched\n    \"/another_project/priv/static\", # Contents of this directory is not watched\n  ],\n  backend: :fs_poll,\n  backend_opts: [\n    interval: 500\n  ]\n```","ref":"readme.html#backends"},{"type":"extras","title":"Skipping remote CSS reload - README","doc":"All stylesheets are reloaded without a page refresh anytime a style is detected as having changed. In certain cases such as serving stylesheets from a remote host, you may wish to prevent unnecessary reload of these stylesheets during development. For this, you can include a `data-no-reload` attribute on the link tag, ie:","ref":"readme.html#skipping-remote-css-reload"},{"type":"extras","title":"Differences between [Phoenix.CodeReloader](https://hexdocs.pm/phoenix/Phoenix.CodeReloader.html#content) - README","doc":"[Phoenix.CodeReloader](https://hexdocs.pm/phoenix/Phoenix.CodeReloader.html#content) recompiles code in the lib directory. This means that if you change anything in the lib directory (such as a context) then the Elixir code will be reloaded and used on your next request.\n\nIn contrast, this project adds a plug which injects some JavaScript into your page with a WebSocket connection to the server. When you make a change to anything in your config for live\\_reload (JavaScript, stylesheets, templates and views by default) then the page will be reloaded in response to a message sent via the WebSocket. If the change was to an Elixir file then it will be recompiled and served when the page is reloaded. If it is JavaScript or CSS, then only assets are reloaded, without triggering a full page load.","ref":"readme.html#differences-between-phoenix-codereloader-https-hexdocs-pm-phoenix-phoenix-codereloader-html-content"},{"type":"extras","title":"License - README","doc":"[Same license as Phoenix](https://github.com/phoenixframework/phoenix/blob/master/LICENSE.md).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.6.0 (2025-04-10) - Changelog","doc":"* Enhancements\n  * Add support for `__RELATIVEFILE__` when invoking editors\n  * Change the default target window to `:parent` to not reload the whole page if a Phoenix app is shown inside an iframe. You can get the old behavior back by setting the `:target_window` option to `:top`:\n    ```elixir\n    config :phoenix_live_reload, MyAppWeb.Endpoint,\n      target_window: :top,\n      ...\n    ```\n\n* Bug fixes\n  * Inject iframe if web console logger is enabled but there are no patterns\n  * Allow web console to shutdown cleanly","ref":"changelog.html#1-6-0-2025-04-10"},{"type":"extras","title":"1.5.3 (2024-03-27) - Changelog","doc":"* Bug fixes\n  * Fix warnings on earlier Elixir versions\n  * Use darkcyan for log levels","ref":"changelog.html#1-5-3-2024-03-27"},{"type":"extras","title":"1.5.2 (2024-03-11) - Changelog","doc":"* Bug fixes\n  * Fix CSS updates failing with errors\n  * Fix logging errors caused by unknown server log types","ref":"changelog.html#1-5-2-2024-03-11"},{"type":"extras","title":"1.5.1 (2024-02-29) - Changelog","doc":"* Bug fixes\n  * Fix regression on Elixir v1.14 and earlier","ref":"changelog.html#1-5-1-2024-02-29"},{"type":"extras","title":"1.5.0 (2024-02-29) - Changelog","doc":"* Improvements\n  * Introduce streaming server logs to the browser's web console with the new `:web_console_logger` endpoint configuration\n  * Introduce `openEditorAtCaller` and `openEditorAtDef` client functions for opening the developer's configured `PLUG_EDITOR` to the elixir source file/line given a DOM element\n  * Dispatch `\"phx:live_reload:attached\"` to parent window when live reload is attached to server and awaiting changes","ref":"changelog.html#1-5-0-2024-02-29"},{"type":"extras","title":"1.4.1 (2022-11-29) - Changelog","doc":"* Improvements\n  * Support new `:notify` configuration for third-party integration to file change events","ref":"changelog.html#1-4-1-2022-11-29"},{"type":"extras","title":"1.4.0 (2022-10-29) - Changelog","doc":"* Improvements\n  * Allow reload events to be debounced instead of triggered immediately\n  * Add option to trigger full page reloads on css changes\n* Bug fixes\n  * Handle false positives on ` ` tags","ref":"changelog.html#1-4-0-2022-10-29"},{"type":"extras","title":"1.3.3 (2021-07-06) - Changelog","doc":"* Improvements\n  * Do not attempt to fetch source map for phoenix.js","ref":"changelog.html#1-3-3-2021-07-06"},{"type":"extras","title":"1.3.2 (2021-06-21) - Changelog","doc":"* Improvements\n  * Allow reload `:target_window` to be configured","ref":"changelog.html#1-3-2-2021-06-21"},{"type":"extras","title":"1.3.1 (2021-04-12) - Changelog","doc":"* Bug fixes\n  * Use width=0 and height=0 on iframe","ref":"changelog.html#1-3-1-2021-04-12"},{"type":"extras","title":"1.3.0 (2020-11-03) - Changelog","doc":"This release requires Elixir v1.6+.\n\n* Enhancements\n  * Use `hidden` attribute instead of `style=\"display: none\"`\n  * Fix warnings on Elixir v1.11\n\n* Deprecations\n  * `:iframe_class` is deprecated in favor of `:iframe_attrs`","ref":"changelog.html#1-3-0-2020-11-03"},{"type":"extras","title":"1.2.4 (2020-06-10) - Changelog","doc":"* Bug fixes\n  * Fix a bug related to improper live reload interval","ref":"changelog.html#1-2-4-2020-06-10"},{"type":"extras","title":"1.2.3 (2020-06-10) - Changelog","doc":"* Enhancements\n  * Support the iframe_class option for live reload","ref":"changelog.html#1-2-3-2020-06-10"},{"type":"extras","title":"1.2.2 (2020-05-13) - Changelog","doc":"* Enhancements\n  * Support the suffix option","ref":"changelog.html#1-2-2-2020-05-13"},{"type":"extras","title":"1.2.1 (2019-05-24) - Changelog","doc":"* Enhancements\n  * Allow custom file_system backend options","ref":"changelog.html#1-2-1-2019-05-24"},{"type":"extras","title":"1.2.0 (2018-11-07) - Changelog","doc":"* Enhancements\n  * Support Phoenix 1.4 transport changes","ref":"changelog.html#1-2-0-2018-11-07"},{"type":"extras","title":"1.1.7 (2018-10-10) - Changelog","doc":"* Enhancements\n  * Relax version requirements to support Phoenix 1.4","ref":"changelog.html#1-1-7-2018-10-10"},{"type":"extras","title":"1.1.6 (2018-09-28) - Changelog","doc":"* Enhancements\n  * Allow file system watcher backend to be configured\n  * Add `:fs_poll` backend as fallback for generic OS support","ref":"changelog.html#1-1-6-2018-09-28"},{"type":"extras","title":"1.1.5 - Changelog","doc":"* Bug fix\n  * Use proper default interval of 100ms","ref":"changelog.html#1-1-5"},{"type":"extras","title":"1.1.4 - Changelog","doc":"* Enhancements\n  * Support `:interval` configuration for cases where the live reloading was triggering too fast\n\n* Bug fix\n  * Support IE11\n  * Fix CSS reloading in iframe","ref":"changelog.html#1-1-4"},{"type":"extras","title":"1.1.3 (2017-09-25) - Changelog","doc":"* Bug fix\n  * Do not return unsupported `:ignore` from live channel","ref":"changelog.html#1-1-3-2017-09-25"},{"type":"extras","title":"1.1.2 (2017-09-25) - Changelog","doc":"* Enhancements\n  * Improve error messages","ref":"changelog.html#1-1-2-2017-09-25"},{"type":"extras","title":"1.1.1 (2017-08-27) - Changelog","doc":"* Enhancements\n  * Bump `:file_system` requirement\n\n* Bug fixes\n  * Do not raise when response has no body","ref":"changelog.html#1-1-1-2017-08-27"},{"type":"extras","title":"1.1.0 (2017-08-10) - Changelog","doc":"* Enhancements\n  * Use `:file_system` for file change notifications for improved reliability","ref":"changelog.html#1-1-0-2017-08-10"},{"type":"extras","title":"1.0.8 (2017-02-01) - Changelog","doc":"* Enhancements\n  * Revert to `:fs` 0.9.1 to side-step rebar build problems","ref":"changelog.html#1-0-8-2017-02-01"},{"type":"extras","title":"1.0.7 (2017-01-18) - Changelog","doc":"* Enhancements\n  * Update to latest `:fs` 2.12","ref":"changelog.html#1-0-7-2017-01-18"},{"type":"extras","title":"1.0.6 (2016-11-29) - Changelog","doc":"* Bug fixes\n  * Remove warnings on Elixir v1.4\n  * Do not try to access the endpoint if it is no longer loaded","ref":"changelog.html#1-0-6-2016-11-29"},{"type":"extras","title":"1.0.5 (2016-05-04) - Changelog","doc":"* Bug fixes\n  * Do not include hard earmark requirement","ref":"changelog.html#1-0-5-2016-05-04"},{"type":"extras","title":"1.0.4 (2016-04-29) - Changelog","doc":"* Enhancements\n  * Support Phoenix v1.2","ref":"changelog.html#1-0-4-2016-04-29"},{"type":"extras","title":"1.0.3 (2016-01-11) - Changelog","doc":"* Enhancements\n  * Log whenever a live reload event is sent","ref":"changelog.html#1-0-3-2016-01-11"},{"type":"extras","title":"1.0.2 (2016-01-07) - Changelog","doc":"* Bug fixes\n  * Fix issue where iframe path did not respect script_name","ref":"changelog.html#1-0-2-2016-01-07"},{"type":"extras","title":"1.0.1 (2015-09-18) - Changelog","doc":"* Bug fixes\n  * Fix issue causing stylesheet link taps to duplicate on reload","ref":"changelog.html#1-0-1-2015-09-18"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}